<h1 align="center">
    AIOproxytest
</h1>

<h3 align="center">
    aiopt is a simple asynchronous lib for testing proxy servers
</h3>

<div align="center">
    <img src=".github/aiopt.png" align="center">
</div>

---




